@@ -1,3 +1,4 @@
+from copy import copy
 from django import forms
 from django.conf import settings
 from django.contrib.auth.models import User
@@ -15,6 +16,12 @@ if hasattr(settings, "ARMSTRONG_INITIAL_STATE"):
 
 
 class BaseDonationForm(forms.Form):
+    """
+    Provides the basic fields common to all donation forms
+
+    This is meant to be overridden by the forms returned by a
+    ``Backend.get_form_class`` to provide specific implementations.
+    """
     first_name = forms.CharField()
     last_name = forms.CharField()
     amount = forms.DecimalField(decimal_places=2)
@@ -63,15 +70,22 @@ class BaseDonationForm(forms.Form):
         }
 
     def is_valid(self, donation_only=False):
-        donation_is_valid = super(BaseDonationForm, self).is_valid()
+        parent = super(BaseDonationForm, self)
+        donation_is_valid = parent.is_valid()
         if not donation_is_valid and "amount" in self.errors:
             donation_type_field = self.add_prefix("donation_type_pk")
             if donation_type_field in self.data:
                 donation_type_pk = self.data[donation_type_field]
                 try:
-                    models.DonationTypeOption.objects.get(pk=donation_type_pk)
-                    del self.errors["amount"]
-                    donation_is_valid = len(self.errors) is 0
+                    dt = models.DonationTypeOption.objects.get(pk=donation_type_pk)
+
+                    # We've made it this far, so create a copy of the data (which is
+                    # most likely an immutable `QueryDict`) and adjust the amount to
+                    # the correct value before re-running is_valid().
+                    self.data = copy(self.data)
+                    self.data["amount"] = dt.amount
+                    self._errors = None
+                    donation_is_valid = parent.is_valid()
                 except models.DonationTypeOption.DoesNotExist:
                     donation_is_valid = False
 
@@ -116,7 +130,26 @@ class BaseDonationForm(forms.Form):
         return donation
 
 
-class CreditCardDonationForm(BaseDonationForm):
+class StripSensitiveFields(object):
+    """
+    Mixin for stripping sensitive information from an invalid form
+
+    This is meant to be used by a ``Form`` object and strips the fields
+    listed in ``fields_to_strip`` if ``is_valid`` fails.
+    """
+    fields_to_strip = []
+
+    def is_valid(self, *args, **kwargs):
+        r = super(StripSensitiveFields, self).is_valid(*args, **kwargs)
+        if not r and self.fields_to_strip:
+            empty_values = [""] * len(self.fields_to_strip)
+            new_data = dict(zip(self.fields_to_strip, empty_values))
+            self.data = copy(self.data)
+            self.data.update(new_data)
+        return r
+
+
+class CreditCardDonationForm(StripSensitiveFields, BaseDonationForm):
     """
     Form representing the credit card donation process for Authorize.net
 
@@ -133,12 +166,27 @@ class CreditCardDonationForm(BaseDonationForm):
     expiration_month = forms.ChoiceField(choices=MONTH_CHOICES)
     expiration_year = forms.ChoiceField(choices=YEAR_CHOICES)
 
-    def get_data_for_charge(self, donor, **kwargs):
+    fields_to_strip = ["card_number", "ccv_code", ]
+
+    def get_data_for_charge(self, donation, **kwargs):
+        """
+        Returns the data for charges
+
+        This is used to build a dictionary of data that can not be
+        retrieved directly from the ``Donation`` model.
+        """
         raise NotImplementedError
 
 
 class AuthorizeDonationForm(CreditCardDonationForm):
-    def get_data_for_charge(self, donor, recurring=False):
+    """
+    Represents a ``CreditCardDonationForm`` form for Authorize.net
+
+    This form is returned by the ``AuthorizeNetBackend.get_form_class``
+    and should not be accessed directly.
+    """
+    def get_data_for_charge(self, donation, recurring=False):
+        """Returns the data for charges"""
         self.is_valid()
         card_number = "card_num" if not recurring else "card_number"
         data = {
@@ -158,12 +206,14 @@ class AuthorizeDonationForm(CreditCardDonationForm):
 
 
 class DonorForm(forms.ModelForm):
+    """Simple ``ModelForm`` for the ``Donor`` model"""
     class Meta:
         model = models.Donor
         excludes = ("address", "mailing_address", )
 
 
 class DonorAddressForm(forms.ModelForm):
+    """Simple ``ModelForm`` for the ``DonorAddress`` model"""
     address = forms.CharField(widget=forms.Textarea)
 
     class Meta:
